pysmug.smugmug.SmugMug

Package pysmug :: Module smugmug :: Class SmugMug |
[hide private]
[frames] | no frames]

# Class SmugMug

source code

    object --+
             |
      SmugBase --+
                 |
                SmugMug

Serial version of a SmugMug client.

Instance Methods | [hide private]
_perform(self, c) Perform the low-level communication with SmugMug. | source code
_login(self, handler, keywords, **kwargs) | source code
login_anonymously(self, **kwargs) Login into SmugMug anonymously using the API key. | source code
login_withHash(self, **kwargs) Login into SmugMug with user id, password hash and API key. | source code
login_withPassword(self, **kwargs) Login into SmugMug with email address, password and API key. | source code
categories_getTree(self) Return a tree of categories and sub-categories. | source code
Inherited from `SmugBase`: `__getattr__`, `__init__`, `batch`, `images_upload` Inherited from `SmugBase` (private): `_handle_response`, `_make_handler`, `_new_connection`, `_prepare_keywords` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Instance Variables | [hide private]
Inherited from `SmugBase`: `proxy`, `secure`, `sessionId`

Properties | [hide private]
Inherited from `SmugBase`: `protocol` Inherited from `object`: `__class__`

Method Details | [hide private]

### _perform(self, c) | source code
Perform the low-level communication with SmugMug. Parameters: `c` - a pending request Overrides: SmugBase._perform

### login_anonymously(self, **kwargs) | source code
Login into SmugMug anonymously using the API key. Parameters: `APIKey` - a SmugMug api key Returns: the SmugMug instance with a session established

### login_withHash(self, **kwargs) | source code
Login into SmugMug with user id, password hash and API key. Parameters: `userId` - the account holder's user id `passwordHash` - the account holder's password hash `APIKey` - a SmugMug api key Returns: the SmugMug instance with a session established

### login_withPassword(self, **kwargs) | source code
Login into SmugMug with email address, password and API key. Parameters: `emailAddress` - the account holder's email address `password` - the account holder's password `APIKey` - a SmugMug api key Returns: the SmugMug instance with a session established

### categories_getTree(self) | source code
Return a tree of categories and sub-categories. The format of the response tree:
     {'Category1': {'id': 41, 'SubCategories': {}},
      'Category2': {'id':  3,
                    'SubCategories': {'One': 4493,
                                      'Two': 4299}},
     }
The primary purpose for this method is to provide an easy mapping between name and id. This method is not a standard smugmug method. To Do: how can this be integrated with SmugBatch?